==> zio-aws-iot_2.12-5.17.191.2-sources.jar: zio/aws/iot/model/ListThingGroupsForThingResponse.scala <==
package zio.aws.iot.model
import zio.ZIO
import zio.aws.iot.model.primitives.NextToken
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListThingGroupsForThingResponse(
    thingGroups: Optional[Iterable[zio.aws.iot.model.GroupNameAndArn]] =
      Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot.model.ListThingGroupsForThingResponse = {
    import ListThingGroupsForThingResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot.model.ListThingGroupsForThingResponse
      .builder()
      .optionallyWith(
        thingGroups.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.thingGroups)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.iot.model.ListThingGroupsForThingResponse.ReadOnly =
    zio.aws.iot.model.ListThingGroupsForThingResponse.wrap(buildAwsValue())
}
object ListThingGroupsForThingResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot.model.ListThingGroupsForThingResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot.model.ListThingGroupsForThingResponse =
      zio.aws.iot.model.ListThingGroupsForThingResponse(
        thingGroups.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def thingGroups: Optional[List[zio.aws.iot.model.GroupNameAndArn.ReadOnly]]
    def nextToken: Optional[NextToken]
    def getThingGroups
        : ZIO[Any, AwsError, List[zio.aws.iot.model.GroupNameAndArn.ReadOnly]] =
      AwsError.unwrapOptionField("thingGroups", thingGroups)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot.model.ListThingGroupsForThingResponse
  ) extends zio.aws.iot.model.ListThingGroupsForThingResponse.ReadOnly {
    override val thingGroups
        : Optional[List[zio.aws.iot.model.GroupNameAndArn.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.thingGroups())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.iot.model.GroupNameAndArn.wrap(item)
          }.toList
        )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.iot.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot.model.ListThingGroupsForThingResponse
  ): zio.aws.iot.model.ListThingGroupsForThingResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-iot_3-5.17.104.11-sources.jar: zio/aws/iot/model/ListThingGroupsForThingResponse.scala <==
package zio.aws.iot.model
import zio.ZIO
import zio.aws.iot.model.primitives.NextToken
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ListThingGroupsForThingResponse(
    thingGroups: Option[Iterable[zio.aws.iot.model.GroupNameAndArn]] = None,
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot.model.ListThingGroupsForThingResponse = {
    import ListThingGroupsForThingResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot.model.ListThingGroupsForThingResponse
      .builder()
      .optionallyWith(
        thingGroups.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.thingGroups)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.iot.model.ListThingGroupsForThingResponse.ReadOnly =
    zio.aws.iot.model.ListThingGroupsForThingResponse.wrap(buildAwsValue())
}
object ListThingGroupsForThingResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot.model.ListThingGroupsForThingResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot.model.ListThingGroupsForThingResponse =
      zio.aws.iot.model.ListThingGroupsForThingResponse(
        thingGroups.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def thingGroups: Option[List[zio.aws.iot.model.GroupNameAndArn.ReadOnly]]
    def nextToken: Option[NextToken]
    def getThingGroups
        : ZIO[Any, AwsError, List[zio.aws.iot.model.GroupNameAndArn.ReadOnly]] =
      AwsError.unwrapOptionField("thingGroups", thingGroups)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot.model.ListThingGroupsForThingResponse
  ) extends zio.aws.iot.model.ListThingGroupsForThingResponse.ReadOnly {
    override val thingGroups
        : Option[List[zio.aws.iot.model.GroupNameAndArn.ReadOnly]] = scala
      .Option(impl.thingGroups())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.iot.model.GroupNameAndArn.wrap(item)
        }.toList
      )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.iot.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot.model.ListThingGroupsForThingResponse
  ): zio.aws.iot.model.ListThingGroupsForThingResponse.ReadOnly = new Wrapper(
    impl
  )
}
